pype32.excep.PyPe32Exception

Package pype32 :: Module excep :: Class PyPe32Exception |
[hide private]
[frames] | no frames]

# Class PyPe32Exception

source code

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
                                  PyPe32Exception

Known Subclasses:
  - ArrayTypeException
  - , DataLengthException
  - , DataMismatchException
  - , DirectoryEntriesLengthException
  - , DirectoryEntryException
  - , InstanceErrorException
  - , InvalidParameterException
  - , NotValidPathException
  - , ReadDataOffsetException
  - , SectionHeadersException
  - , TypeNotSupportedException
  - , WriteDataOffsetException
  - , WrongOffsetValueException
  - , PEException

Base exception class.

Instance Methods | [hide private]
Inherited from `exceptions.Exception`: `__init__`, `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__str__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`